@@ -21,3 +21,12 @@ class SystemMetricsRequiredElasticSearch(BenchmarkOperatorError):
     def __init__(self):
         self.message = "System metrics is required ElasticSearch, set 'SYSTEM_METRICS' to False"
         super(SystemMetricsRequiredElasticSearch, self).__init__(self.message)
+
+
+class PrometheusSnapshotFailed(BenchmarkOperatorError):
+    """
+    Prometheus snapshot failed
+    """
+    def __init__(self, err):
+        self.message = f'Prometheus snapshot failed: {err}'
+        super(PrometheusSnapshotFailed, self).__init__(self.message)
