@@ -8,8 +8,8 @@ from typeguard import typechecked
 
 from benchmark_runner.common.logger.logger_time_stamp import logger_time_stamp, logger
 from benchmark_runner.common.oc.oc import OC
-from benchmark_runner.benchmark_operator.workload_flavors.benchmark_operator_template_operations import BenchmarkOperatorTemplateOperations
-from benchmark_runner.common.elasticsearch.es_operations import ESOperations
+from benchmark_runner.common.template_operations.template_operations import TemplateOperations
+from benchmark_runner.common.elasticsearch.elasticsearch_operations import ElasticSearchOperations
 from benchmark_runner.common.ssh.ssh import SSH
 from benchmark_runner.benchmark_operator.benchmark_operator_exceptions import OCSNonInstalled, SystemMetricsRequiredElasticSearch
 from benchmark_runner.main.environment_variables import environment_variables
@@ -31,6 +31,7 @@ class BenchmarkOperatorWorkloadsOperations:
         self._runner_version = self._environment_variables_dict.get('build_version', '')
         self._run_type = self._environment_variables_dict.get('run_type', '')
         self._workloads_ocs_pvc = list(self._environment_variables_dict.get('workloads_ocs_pvc', ''))
+        self._ocs_pvc = self._environment_variables_dict.get('ocs_pvc', '')
         self._system_metrics = self._environment_variables_dict.get('system_metrics', '')
         self._elasticsearch = self._environment_variables_dict.get('elasticsearch', '')
         self._run_artifacts = self._environment_variables_dict.get('run_artifacts', '')
@@ -42,7 +43,9 @@ class BenchmarkOperatorWorkloadsOperations:
         self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', '')
         self._kubeadmin_password = self._environment_variables_dict.get('kubeadmin_password', '')
         self._dir_path = f'{os.path.dirname(os.path.realpath(__file__))}'
-        self._save_artifacts_local = self._environment_variables_dict.get('save_artifacts_local', '')
+        self._pin_node_benchmark_operator = self._environment_variables_dict.get('pin_node_benchmark_operator', '')
+        self._pin_node1 = self._environment_variables_dict.get('pin_node1', '')
+        self._pin_node2 = self._environment_variables_dict.get('pin_node2', '')
         self._es_host = self._environment_variables_dict.get('elasticsearch', '')
         self._es_port = self._environment_variables_dict.get('elasticsearch_port', '')
         self._es_user = self._environment_variables_dict.get('elasticsearch_user', '')
@@ -51,13 +54,13 @@ class BenchmarkOperatorWorkloadsOperations:
         self._ssh = SSH()
         # Elasticsearch connection
         if self._es_host and self._es_port:
-            self.__es_operations = ESOperations(es_host=self._es_host,
-                                                es_port=self._es_port,
-                                                es_user=self._es_user,
-                                                es_password=self._es_password,
-                                                timeout=self._timeout)
-        # Generate workload_flavors class
-        self._template = BenchmarkOperatorTemplateOperations()
+            self.__es_operations = ElasticSearchOperations(es_host=self._es_host,
+                                                           es_port=self._es_port,
+                                                           es_user=self._es_user,
+                                                           es_password=self._es_password,
+                                                           timeout=self._timeout)
+        # Generate template class
+        self._template = TemplateOperations(workload=self._workload)
         # set oc login
         self._oc = self.set_login(kubeadmin_password=self._kubeadmin_password)
         # PrometheusSnapshot
@@ -70,9 +73,8 @@ class BenchmarkOperatorWorkloadsOperations:
         :param kubeadmin_password:
         :return:
         """
-        if kubeadmin_password:
-            self._oc = OC(kubeadmin_password=kubeadmin_password)
-            self._oc.login()
+        self._oc = OC(kubeadmin_password=kubeadmin_password)
+        self._oc.login()
         return self._oc
 
     def __check_elasticsearch_exist_for_system_metrics(self):
@@ -196,7 +198,8 @@ class BenchmarkOperatorWorkloadsOperations:
         self._oc.wait_for_pod_completed(label='app=system-metrics-collector', workload=workload)
         # verify that data upload to elastic search
         if self._es_host:
-            self._verify_es_data_uploaded(index=es_index, uuid=self._oc.get_long_uuid(workload=workload), fast_check = True)
+            # workload: system metrics, in case of uperf take timestamp and not uperf_ts
+            self._verify_elasticsearch_data_uploaded(index=es_index, uuid=self._oc.get_long_uuid(workload=workload), workload='system-metrics', fast_check = True)
 
     def __get_metadata(self, kind: str = None, database: str = None, status: str = None, run_artifacts_url: str = None) -> dict:
         """
@@ -214,7 +217,10 @@ class BenchmarkOperatorWorkloadsOperations:
                     'ocs_version': self._oc.get_ocs_version(),
                     'runner_version': self._runner_version,
                     'version': int(self._runner_version.split('.')[-1]),
-                    'ci_date': datetime.datetime.now().strftime(date_format)}
+                    'ci_date': datetime.datetime.now().strftime(date_format),
+                    'pin_node_benchmark_operator': self._pin_node_benchmark_operator,
+                    'pin_node1': self._pin_node1,
+                    'pin_node2': self._pin_node2}
         if kind:
             metadata.update({'kind': kind})
         if status:
@@ -236,7 +242,7 @@ class BenchmarkOperatorWorkloadsOperations:
         return metadata
 
     @logger_time_stamp
-    def _update_es_index(self, index: str, id: str, kind: str, status: str, run_artifacts_url: str, database: str = ''):
+    def _update_elasticsearch_index(self, index: str, id: str, kind: str, status: str, run_artifacts_url: str, database: str = ''):
         """
         This method update elasticsearch id
         :param index:
@@ -247,9 +253,9 @@ class BenchmarkOperatorWorkloadsOperations:
         :param run_artifacts_url:
         :return:
         """
-        self.__es_operations.update_es_index(index=index, id=id, metadata=self.__get_metadata(kind=kind, database=database, status=status, run_artifacts_url=run_artifacts_url))
+        self.__es_operations.update_elasticsearch_index(index=index, id=id, metadata=self.__get_metadata(kind=kind, database=database, status=status, run_artifacts_url=run_artifacts_url))
 
-    def _upload_to_es(self, index: str, kind: str, status: str, run_artifacts_url: str, database: str = ''):
+    def _upload_to_elasticsearch(self, index: str, kind: str, status: str, run_artifacts_url: str, database: str = ''):
         """
         This method upload to elasticsearch
         :param index:
@@ -259,17 +265,21 @@ class BenchmarkOperatorWorkloadsOperations:
         :param database:
         :return:
         """
-        self.__es_operations.upload_to_es(index=index, data=self.__get_metadata(kind=kind, database=database, status=status, run_artifacts_url=run_artifacts_url))
+        self.__es_operations.upload_to_elasticsearch(index=index, data=self.__get_metadata(kind=kind, database=database, status=status, run_artifacts_url=run_artifacts_url))
 
-    def _verify_es_data_uploaded(self, index: str, uuid: str, fast_check: bool = False):
+    def _verify_elasticsearch_data_uploaded(self, index: str, uuid: str, workload: str = '', fast_check: bool = False):
         """
         This method verify that elasticsearch data uploaded
         :param index:
         :param uuid:
+        :param workload:
         :param fast_check:
         :return: ids
         """
-        return self.__es_operations.verify_es_data_uploaded(index=index, uuid=uuid, workload=self._workload_name, fast_check=fast_check)
+        if workload:
+            return self.__es_operations.verify_elasticsearch_data_uploaded(index=index, uuid=uuid, workload=workload, fast_check=fast_check)
+        else:
+            return self.__es_operations.verify_elasticsearch_data_uploaded(index=index, uuid=uuid, workload=self._workload_name, fast_check=fast_check)
 
     def _create_vm_log(self, labels: list) -> str:
         """
@@ -324,7 +334,8 @@ class BenchmarkOperatorWorkloadsOperations:
         :return: run artifacts url
         """
         self.__create_pod_log(label='benchmark-controller-manager')
-        self.__create_pod_log(label='system-metrics')
+        if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+            self.__create_pod_log(label='system-metrics')
         # for vm call to create_vm_log
         if pod:
             # workload that contains 2 pods
@@ -410,7 +421,7 @@ class BenchmarkOperatorWorkloadsOperations:
         :return:
         """
         workload_name = self._workload.split('_')
-        if workload_name[0] in self._workloads_ocs_pvc:
+        if self._ocs_pvc == 'True' and workload_name[0] in self._workloads_ocs_pvc:
             if not self._oc.is_ocs_installed():
                 raise OCSNonInstalled()
 
@@ -420,9 +431,10 @@ class BenchmarkOperatorWorkloadsOperations:
         This method delete all pod in namespace
         :return:
         """
-        self._oc.delete_all_resources()
+        # make undeploy benchmark controller manager if exist
+        self.make_undeploy_benchmark_controller_manager_if_exist(runner_path=environment_variables.environment_variables_dict['runner_path'])
         if 'hammerdb' in self._workload:
-            self._oc.delete_all_resources(namespace=f"{self._workload.split('_')[2]}-db")
+            self._oc.delete_all_resources(resources=['deployments', 'services', 'pvc'], namespace=f"{self._workload.split('_')[2]}-db")
 
     def initialize_workload(self):
         """
@@ -432,12 +444,10 @@ class BenchmarkOperatorWorkloadsOperations:
         self.delete_all()
         # check that there is elasticsearch when system metric is True
         self.__check_elasticsearch_exist_for_system_metrics()
-        # make undeploy benchmark controller manager if exist
-        self.make_undeploy_benchmark_controller_manager_if_exist(runner_path=environment_variables.environment_variables_dict['runner_path'])
         # make deploy benchmark controller manager
         self.make_deploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
         self.ocs_pvc_verification()
-        self._template.generate_yamls(workload=self._workload)
+        self._template.generate_yamls()
         self.start_prometheus()
 
     def finalize_workload(self):
@@ -447,6 +457,4 @@ class BenchmarkOperatorWorkloadsOperations:
         """
         self.end_prometheus()
         self.upload_run_artifacts_to_s3()
-        # make undeploy benchmark controller manager
-        self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
         self.delete_all()
