@@ -44,14 +44,24 @@ class EnvironmentVariables:
                                                          'hammerdb_pod_mariadb', 'hammerdb_vm_mariadb', 'hammerdb_kata_mariadb',
                                                          'hammerdb_pod_postgres', 'hammerdb_vm_postgres', 'hammerdb_kata_postgres',
                                                          'hammerdb_pod_mssql', 'hammerdb_vm_mssql', 'hammerdb_kata_mssql',
-                                                         'vdbench_pod', 'vdbench_kata']
-        # benchmark-operator workloads
-        self._environment_variables_dict['benchmark_operator_workloads'] = ['stressng', 'uperf', 'hammerdb']
-        # benchmark-runner workloads - customs
-        self._environment_variables_dict['benchmark_runner_workloads'] = ['vdbench']
+                                                         'vdbench_pod', 'vdbench_kata', 'vdbench_vm']
+        # benchmark-operator workload types
+        self._environment_variables_dict['workload_namespaces'] = {
+            'stressng': 'benchmark-operator',
+            'hammerdb': 'benchmark-operator',
+            'uperf': 'benchmark-operator',
+            'vdbench': 'benchmark-runner',
+        }
+
         # Choose default namespace
-        default_namespace = 'benchmark-runner' if self._environment_variables_dict['workload'].split('_')[0] in list(self._environment_variables_dict['benchmark_runner_workloads']) else 'benchmark-operator'
-        self._environment_variables_dict['namespace'] = os.environ.get('NAMESPACE', default_namespace)
+        base_workload = self._environment_variables_dict['workload'].split('_')[0]
+        if base_workload in self._environment_variables_dict['workload_namespaces']:
+            default_namespace = self._environment_variables_dict['workload_namespaces'][base_workload]
+            self._environment_variables_dict['namespace'] = os.environ.get('NAMESPACE', default_namespace)
+        else:
+            # TBD if this is not set
+            self._environment_variables_dict['namespace'] = 'benchmark-operator'
+
         # run workload with ocs pvc True/False. True=OCS, False=Ephemeral
         self._environment_variables_dict['ocs_pvc'] = os.environ.get('OCS_PVC', 'True')
         # Workloads that required OCS
@@ -60,14 +70,15 @@ class EnvironmentVariables:
         self._environment_variables_dict['build_version'] = os.environ.get('BUILD_VERSION', '1.0.0')
         # collect system metrics True/False
         self._environment_variables_dict['system_metrics'] = os.environ.get('SYSTEM_METRICS', 'True')
-        # CI status update once at the end of CI Pass/Failed
+        # CI status update once at the end of CI pass/failed
         self._environment_variables_dict['ci_status'] = os.environ.get('CI_STATUS', '')
         # Valid run types
         self._environment_variables_dict['run_types'] = ['test_ci', 'func_ci', 'perf_ci']
         # Run type test_ci/func_ci/perf_ci, default test_ci same environment as func_ci
         self._environment_variables_dict['run_type'] = os.environ.get('RUN_TYPE', 'test_ci')
+
         # Run uuid
-        self._environment_variables_dict['uuid'] = str(uuid4())
+        self._environment_variables_dict['uuid'] = os.environ.get('UUID', str(uuid4()))
         self._environment_variables_dict['trunc_uuid'] = self._environment_variables_dict['uuid'].split('-')[0]
         # Benchmark runner IBM Cloud Object Storage run artifacts hierarchy, not part of a POSIX path ('/' a key seperator, '-' file name convenstion )
         self._environment_variables_dict['date_key'] = datetime.datetime.now().strftime("%Y/%m/%d")
@@ -158,7 +169,7 @@ class EnvironmentVariables:
         # Benchmark runner run artifacts url
         self._environment_variables_dict['run_artifacts_url'] = os.environ.get(f'{self.__ocp_env_flavor}_RUN_ARTIFACTS_URL', '')
 
-        # Parameters below related to 'update_ci_status()'
+        # Parameters below related to 'update_ci_status()' - No need to configure update auto by ci
         # CI run time
         self._environment_variables_dict['ci_minutes_time'] = os.environ.get('CI_MINUTES_TIME', 0)
         # Get this parameter from install resource process
@@ -214,5 +225,14 @@ class EnvironmentVariables:
         """
         self._environment_variables_dict = value
 
+    def get_workload_namespace(self, workload: str):
+        """
+        Return the workload namespace for a given workload
+        """
+        if workload in self._environment_variables_dict['workloads'] and workload.split('_')[0] in self._environment_variables_dict['workload_namespaces']:
+            return self._environment_variables_dict['workload_namespaces'][workload.split('_')[0]]
+        else:
+            return None
+
 
 environment_variables = EnvironmentVariables()
