@@ -8,12 +8,12 @@ from csv import DictReader
 from benchmark_runner.common.logger.logger_time_stamp import logger_time_stamp
 from benchmark_runner.workloads.workloads_exceptions import OCSNonInstalled
 from benchmark_runner.common.oc.oc import OC
-from benchmark_runner.common.elasticsearch.es_operations import ESOperations
+from benchmark_runner.common.elasticsearch.elasticsearch_operations import ElasticSearchOperations
 from benchmark_runner.main.environment_variables import environment_variables
 from benchmark_runner.common.clouds.shared.s3.s3_operations import S3Operations
 from benchmark_runner.common.prometheus.prometheus_snapshot import PrometheusSnapshot
 from benchmark_runner.common.prometheus.prometheus_snapshot_exceptions import PrometheusSnapshotError
-from benchmark_runner.workloads.workload_flavors.template_operations import TemplateOperations
+from benchmark_runner.common.template_operations.template_operations import TemplateOperations
 from benchmark_runner.common.clouds.IBM.ibm_operations import IBMOperations
 
 
@@ -26,10 +26,9 @@ class WorkloadsOperations:
         self._environment_variables_dict = environment_variables.environment_variables_dict
         self._workload = self._environment_variables_dict.get('workload', '')
         self._build_version = self._environment_variables_dict.get('build_version', '')
-        self._run_artifacts_path = self._environment_variables_dict.get('run_artifacts_path', '')
         self._workloads_ocs_pvc = list(self._environment_variables_dict.get('workloads_ocs_pvc', ''))
+        self._ocs_pvc = self._environment_variables_dict.get('ocs_pvc', '')
         self._kubeadmin_password = self._environment_variables_dict.get('kubeadmin_password', '')
-        self._oc = OC(kubeadmin_password=self._kubeadmin_password)
         self._run_type = self._environment_variables_dict.get('run_type', '')
         self._trunc_uuid = self._environment_variables_dict.get('trunc_uuid', '')
         self._uuid = self._environment_variables_dict.get('uuid', '')
@@ -37,31 +36,49 @@ class WorkloadsOperations:
         self._key = self._environment_variables_dict.get('key', '')
         self._time_stamp_format = self._environment_variables_dict.get('time_stamp_format', '')
         self._endpoint_url = self._environment_variables_dict.get('endpoint_url', '')
+        self._run_artifacts_path = self._environment_variables_dict.get('run_artifacts_path', '')
+        self._save_artifacts_local = self._environment_variables_dict.get('save_artifacts_local', '')
+        self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', '')
+        self._run_artifacts_url = self._environment_variables_dict.get('run_artifacts_url', '')
+        self._pin_node1 = self._environment_variables_dict.get('pin_node1', '')
+        self._pin_node2 = self._environment_variables_dict.get('pin_node2', '')
         self._es_host = self._environment_variables_dict.get('elasticsearch', '')
         self._es_port = self._environment_variables_dict.get('elasticsearch_port', '')
         self._es_user = self._environment_variables_dict.get('elasticsearch_user', '')
         self._es_password = self._environment_variables_dict.get('elasticsearch_password', '')
-        self._save_artifacts_local = self._environment_variables_dict.get('save_artifacts_local', '')
         self._timeout = int(self._environment_variables_dict.get('timeout', ''))
+        # Elasticsearch connection
         if self._es_host and self._es_port:
-            self.__es_operations = ESOperations(es_host=self._es_host,
-                                              es_port=self._es_port,
-                                              es_user=self._es_user,
-                                              es_password=self._es_password,
-                                              timeout=self._timeout)
-        self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', '')
+            self.__es_operations = ElasticSearchOperations(es_host=self._es_host,
+                                                           es_port=self._es_port,
+                                                           es_user=self._es_user,
+                                                           es_password=self._es_password,
+                                                           timeout=self._timeout)
+        # Generate templates class
+        self._template = TemplateOperations(workload=self._workload)
+        # set oc login
+        self._oc = self.set_login(kubeadmin_password=self._kubeadmin_password)
+        # PrometheusSnapshot
         if self._enable_prometheus_snapshot:
             self._snapshot = PrometheusSnapshot(oc=self._oc, artifacts_path=self._run_artifacts_path, verbose=True)
-        # Generate workload_flavors class
-        self._template = TemplateOperations(workload=self._workload)
+
+    def set_login(self, kubeadmin_password: str = ''):
+        """
+        This method set oc login
+        :param kubeadmin_password:
+        :return: oc instance
+        """
+        self._oc = OC(kubeadmin_password=kubeadmin_password)
+        self._oc.login()
+        return self._oc
 
     @logger_time_stamp
     def delete_all(self):
         """
-        This method delete all pod in namespace
+        This method delete all resources in namespace
         :return:
         """
-        self._oc.delete_all_resources()
+        self._oc.delete_all_resources(resources=['vm', 'pods', 'pvc'])
     
     @logger_time_stamp
     def start_prometheus(self):
@@ -98,11 +115,11 @@ class WorkloadsOperations:
         :return:
         """
         workload_name = self._workload.split('_')
-        if workload_name[0] in self._workloads_ocs_pvc:
+        if self._ocs_pvc == 'True' and workload_name[0] in self._workloads_ocs_pvc:
             if not self._oc.is_ocs_installed():
                 raise OCSNonInstalled()
 
-    def __create_vm_log(self, labels: list) -> str:
+    def _create_vm_log(self, labels: list) -> str:
         """
         This method set vm log per workload
         :param labels: list of labels
@@ -154,26 +171,58 @@ class WorkloadsOperations:
         except ValueError:
             return False
 
-    def _create_run_artifacts(self, pod_name: str, is_pod: bool = True):
+    def _create_pod_run_artifacts(self, pod_name: str):
         """
-        This method create pod logs of benchmark-controller-manager, system-metrics and workload pod
-        :param pod_name: False in case of vm
-        :param is_pod: list of pod names - using it when it different from workload name
+        This method create pod run artifacts
+        :param pod_name: pod name
         :return: run results dict
         """
-        # for vm call to create_vm_log
-        result_dict = {'pod': pod_name}
-        if is_pod:
-            pod_log_file = self.__create_pod_log(pod=pod_name)
-            workload_name = self._environment_variables_dict.get('workload', '').replace('_', '-')
-            the_reader = DictReader(open(pod_log_file, 'r'))
-            for line_dict in the_reader:
-                for key, value in line_dict.items():
-                    if self.__is_float(value):
-                        line_dict[key] = float(value)
-                result_dict[line_dict['Run']] = line_dict
-            result_dict['run_artifacts_url'] = os.path.join(self._environment_variables_dict.get('run_artifacts_url', ''), f'{self.__get_run_artifacts_hierarchy(workload_name=workload_name, is_file=True)}-{self._time_stamp_format}.tar.gz')
-            return result_dict
+        result_list = []
+        pod_log_file = self.__create_pod_log(pod=pod_name)
+        workload_name = self._environment_variables_dict.get('workload', '').replace('_', '-')
+        # csv to dictionary
+        the_reader = DictReader(open(pod_log_file, 'r'))
+        for line_dict in the_reader:
+            for key, value in line_dict.items():
+                if self.__is_float(value):
+                    num = float(value)
+                    line_dict[key] = round(num, 3)
+                elif value == 'n/a':
+                    line_dict[key] = 0.0
+            line_dict['pod_name'] = pod_name
+            line_dict['run_artifacts_url'] = os.path.join(self._run_artifacts_url, f'{self.__get_run_artifacts_hierarchy(workload_name=workload_name, is_file=True)}-{self._time_stamp_format}.tar.gz')
+            result_list.append(dict(line_dict))
+        return result_list
+
+    def _create_vm_run_artifacts(self, vm_name: str, start_stamp: str, end_stamp: str):
+        """
+        This method create vm run artifacts
+        :param vm_name: vm name
+        :param start_stamp: start stamp
+        :param end_stamp: end stamp
+        :return: run results dict
+        """
+        result_list = []
+        results_list = self._oc.extract_vm_results(vm_name=vm_name, start_stamp=start_stamp, end_stamp=end_stamp)
+        workload_name = self._environment_variables_dict.get('workload', '').replace('_', '-')
+        # insert results to csv
+        csv_result_file = os.path.join(self._run_artifacts_path, 'vdbench_vm_result.csv')
+        with open(csv_result_file, 'w') as out:
+            for row in results_list:
+                out.write(f'{row[0].strip()}\n')
+        # csv to dictionary
+        the_reader = DictReader(open(csv_result_file, 'r'))
+        for line_dict in the_reader:
+            for key, value in line_dict.items():
+                if self.__is_float(value):
+                    num = float(value)
+                    line_dict[key] = round(num, 3)
+                elif value == 'n/a':
+                    line_dict[key] = 0.0
+            line_dict['vm_name'] = vm_name
+            line_dict['run_artifacts_url'] = os.path.join(self._run_artifacts_url, f'{self.__get_run_artifacts_hierarchy(workload_name=workload_name, is_file=True)}-{self._time_stamp_format}.tar.gz')
+            result_list.append(dict(line_dict))
+        return result_list
 
     def __make_run_artifacts_tarfile(self, workload: str):
         """
@@ -229,7 +278,9 @@ class WorkloadsOperations:
                     'version': int(self._build_version.split('.')[-1]),
                     'vm_os_version': 'centos8',
                     'ci_date': datetime.datetime.now().strftime(date_format),
-                    'uuid': self._uuid}
+                    'uuid': self._uuid,
+                    'pin_node1': self._pin_node1,
+                    'pin_node2': self._pin_node2}
         if kind:
             metadata.update({'kind': kind})
         if status:
@@ -239,7 +290,7 @@ class WorkloadsOperations:
 
         return metadata
 
-    def _upload_to_es(self, index: str, kind: str, status: str, result: dict = None):
+    def _upload_to_elasticsearch(self, index: str, kind: str, status: str, result: dict = None):
         """
         This method upload to elasticsearch
         :param index:
@@ -248,16 +299,16 @@ class WorkloadsOperations:
         :param result:
         :return:
         """
-        self.__es_operations.upload_to_es(index=index, data=self.__get_metadata(kind=kind, status=status, result=result))
+        self.__es_operations.upload_to_elasticsearch(index=index, data=self.__get_metadata(kind=kind, status=status, result=result))
 
-    def _verify_es_data_uploaded(self, index: str, uuid: str):
+    def _verify_elasticsearch_data_uploaded(self, index: str, uuid: str):
         """
         This method verify that elasticsearch data uploaded
         :param index:
         :param uuid:
         :return:
         """
-        self.__es_operations.verify_es_data_uploaded(index=index, uuid=uuid)
+        self.__es_operations.verify_elasticsearch_data_uploaded(index=index, uuid=uuid)
 
     @logger_time_stamp
     def update_ci_status(self, status: str, ci_minutes_time: int, benchmark_operator_id: str, benchmark_wrapper_id: str, ocp_install_minutes_time: int = 0, ocp_resource_install_minutes_time: int = 0):
@@ -283,7 +334,7 @@ class WorkloadsOperations:
             ocp_install_minutes_time = ibm_operations.get_ocp_install_time()
             ibm_operations.ibm_disconnect()
         metadata.update({'status': status, 'status#': status_dict[status], 'ci_minutes_time': ci_minutes_time, 'benchmark_operator_id': benchmark_operator_id, 'benchmark_wrapper_id': benchmark_wrapper_id, 'ocp_install_minutes_time': ocp_install_minutes_time, 'ocp_resource_install_minutes_time': ocp_resource_install_minutes_time})
-        self.__es_operations.upload_to_es(index=es_index, data=metadata)
+        self.__es_operations.upload_to_elasticsearch(index=es_index, data=metadata)
 
     def initialize_workload(self):
         """
@@ -292,7 +343,7 @@ class WorkloadsOperations:
         """
         self.delete_all()
         self.ocs_pvc_verification()
-        self._template.generate_yaml()
+        self._template.generate_yamls()
         self.start_prometheus()
         
     def finalize_workload(self):
